summaryrefslogtreecommitdiff
path: root/src/mongo/db/commands.h
diff options
context:
space:
mode:
authorNathan Louie <nathan.louie@10gen.com>2018-06-28 11:48:18 -0400
committerNathan Louie <nathan.louie@10gen.com>2018-07-05 16:00:09 -0400
commit96c5d840db4f4279cd9fc8ffe4bdfdc60fcd3984 (patch)
tree174d2a83ed1c613ef5c57daafeb1c15b3973ee16 /src/mongo/db/commands.h
parent1447252f5f44e4a2df4b7e38d4bdef0d88e526c4 (diff)
downloadmongo-96c5d840db4f4279cd9fc8ffe4bdfdc60fcd3984.tar.gz
SERVER-35157 Add transactions latency tracking to OperationLatencyHistogram
Diffstat (limited to 'src/mongo/db/commands.h')
-rw-r--r--src/mongo/db/commands.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/commands.h b/src/mongo/db/commands.h
index a767c8f60c8..966a0d640c7 100644
--- a/src/mongo/db/commands.h
+++ b/src/mongo/db/commands.h
@@ -370,12 +370,12 @@ public:
}
/**
* Returns whether this operation is a read, write, or command.
*
* Commands which implement database read or write logic should override this to return kRead
* or kWrite as appropriate.
*/
- enum class ReadWriteType { kCommand, kRead, kWrite };
+ enum class ReadWriteType { kCommand, kRead, kWrite, kTransaction };
virtual ReadWriteType getReadWriteType() const {
return ReadWriteType::kCommand;
}
@@ -370,12 +370,12 @@ public:
}
/**
- * Returns whether this operation is a read, write, or command.
+ * Returns whether this operation is a read, write, command, or multi-document transaction.
*
* Commands which implement database read or write logic should override this to return kRead